@@ -12,9 +12,8 @@ import platform
 import re
 import sys
 import sysconfig
+import warnings
 from collections import OrderedDict, namedtuple
-from distutils import dist
-from distutils.command.install import SCHEME_KEYS
 from string import digits
 
 VersionInfo = namedtuple("VersionInfo", ["major", "minor", "micro", "releaselevel", "serial"])
@@ -45,8 +44,12 @@ class PythonInfo(object):
             self.pypy_version_info = tuple(u(i) for i in sys.pypy_version_info)
 
         # this is a tuple in earlier, struct later, unify to our own named tuple
-        self.version_info = VersionInfo(*list(u(i) for i in sys.version_info))
-        self.architecture = 64 if sys.maxsize > 2 ** 32 else 32
+        self.version_info = VersionInfo(*[u(i) for i in sys.version_info])
+        self.architecture = 64 if sys.maxsize > 2**32 else 32
+
+        # Used to determine some file names.
+        # See `CPython3Windows.python_zip()`.
+        self.version_nodot = sysconfig.get_config_var("py_version_nodot")
 
         self.version = u(sys.version)
         self.os = u(os.name)
@@ -74,7 +77,31 @@ class PythonInfo(object):
         self.file_system_encoding = u(sys.getfilesystemencoding())
         self.stdout_encoding = u(getattr(sys.stdout, "encoding", None))
 
-        self.sysconfig_paths = {u(i): u(sysconfig.get_path(i, expand=False)) for i in sysconfig.get_path_names()}
+        scheme_names = sysconfig.get_scheme_names()
+
+        if "venv" in scheme_names:
+            self.sysconfig_scheme = "venv"
+            self.sysconfig_paths = {
+                u(i): u(sysconfig.get_path(i, expand=False, scheme=self.sysconfig_scheme))
+                for i in sysconfig.get_path_names()
+            }
+            # we cannot use distutils at all if "venv" exists, distutils don't know it
+            self.distutils_install = {}
+        # debian / ubuntu python 3.10 without `python3-distutils` will report
+        # mangled `local/bin` / etc. names for the default prefix
+        # intentionally select `posix_prefix` which is the unaltered posix-like paths
+        elif sys.version_info[:2] == (3, 10) and "deb_system" in scheme_names:
+            self.sysconfig_scheme = "posix_prefix"
+            self.sysconfig_paths = {
+                i: sysconfig.get_path(i, expand=False, scheme=self.sysconfig_scheme) for i in sysconfig.get_path_names()
+            }
+            # we cannot use distutils at all if "venv" exists, distutils don't know it
+            self.distutils_install = {}
+        else:
+            self.sysconfig_scheme = None
+            self.sysconfig_paths = {u(i): u(sysconfig.get_path(i, expand=False)) for i in sysconfig.get_path_names()}
+            self.distutils_install = {u(k): u(v) for k, v in self._distutils_install().items()}
+
         # https://bugs.python.org/issue22199
         makefile = getattr(sysconfig, "get_makefile_filename", getattr(sysconfig, "_get_makefile_filename", None))
         self.sysconfig = {
@@ -94,9 +121,8 @@ class PythonInfo(object):
 
         self.sysconfig_vars = {u(i): u(sysconfig.get_config_var(i) or "") for i in config_var_keys}
         if self.implementation == "PyPy" and sys.version_info.major == 2:
-            self.sysconfig_vars[u"implementation_lower"] = u"python"
+            self.sysconfig_vars["implementation_lower"] = "python"
 
-        self.distutils_install = {u(k): u(v) for k, v in self._distutils_install().items()}
         confs = {k: (self.system_prefix if v.startswith(self.prefix) else v) for k, v in self.sysconfig_vars.items()}
         self.system_stdlib = self.sysconfig_path("stdlib", confs)
         self.system_stdlib_platform = self.sysconfig_path("platstdlib", confs)
@@ -118,14 +144,36 @@ class PythonInfo(object):
         # note we must choose the original and not the pure executable as shim scripts might throw us off
         return self.original_executable
 
+    def install_path(self, key):
+        result = self.distutils_install.get(key)
+        if result is None:  # use sysconfig if sysconfig_scheme is set or distutils is unavailable
+            # set prefixes to empty => result is relative from cwd
+            prefixes = self.prefix, self.exec_prefix, self.base_prefix, self.base_exec_prefix
+            config_var = {k: "" if v in prefixes else v for k, v in self.sysconfig_vars.items()}
+            result = self.sysconfig_path(key, config_var=config_var).lstrip(os.sep)
+        return result
+
     @staticmethod
     def _distutils_install():
-        # follow https://github.com/pypa/pip/blob/master/src/pip/_internal/locations.py#L95
+        # use distutils primarily because that's what pip does
+        # https://github.com/pypa/pip/blob/main/src/pip/_internal/locations.py#L95
         # note here we don't import Distribution directly to allow setuptools to patch it
+        with warnings.catch_warnings():  # disable warning for PEP-632
+            warnings.simplefilter("ignore")
+            try:
+                from distutils import dist
+                from distutils.command.install import SCHEME_KEYS
+            except ImportError:  # if removed or not installed ignore
+                return {}
+
         d = dist.Distribution({"script_args": "--no-user-cfg"})  # conf files not parsed so they do not hijack paths
         if hasattr(sys, "_framework"):
             sys._framework = None  # disable macOS static paths for framework
-        i = d.get_command_obj("install", create=True)
+
+        with warnings.catch_warnings():  # disable warning for PEP-632
+            warnings.simplefilter("ignore")
+            i = d.get_command_obj("install", create=True)
+
         i.prefix = os.sep  # paths generated are relative to prefix that contains the path sep, this makes it relative
         i.finalize_options()
         result = {key: (getattr(i, "install_{}".format(key))[1:]).lstrip(os.sep) for key in SCHEME_KEYS}
@@ -160,7 +208,7 @@ class PythonInfo(object):
             base = {k: v for k, v in self.sysconfig_vars.items()}
             base.update(config_var)
             config_var = base
-        return pattern.format(**config_var).replace(u"/", sep)
+        return pattern.format(**config_var).replace("/", sep)
 
     def creators(self, refresh=False):
         if self._creators is None or refresh is True:
@@ -177,7 +225,7 @@ class PythonInfo(object):
         )
         if not os.path.exists(path):  # some broken packaging don't respect the sysconfig, fallback to distutils path
             # the pattern include the distribution name too at the end, remove that via the parent call
-            fallback = os.path.join(self.prefix, os.path.dirname(self.distutils_install["headers"]))
+            fallback = os.path.join(self.prefix, os.path.dirname(self.install_path("headers")))
             if os.path.exists(fallback):
                 path = fallback
         return path
@@ -198,7 +246,8 @@ class PythonInfo(object):
 
     def __repr__(self):
         return "{}({!r})".format(
-            self.__class__.__name__, {k: v for k, v in self.__dict__.items() if not k.startswith("_")}
+            self.__class__.__name__,
+            {k: v for k, v in self.__dict__.items() if not k.startswith("_")},
         )
 
     def __str__(self):
@@ -207,7 +256,7 @@ class PythonInfo(object):
             ", ".join(
                 "{}={}".format(k, v)
                 for k, v in (
-                    ("spec", self.spec,),
+                    ("spec", self.spec),
                     (
                         "system"
                         if self.system_executable is not None and self.system_executable != self.executable
@@ -307,12 +356,13 @@ class PythonInfo(object):
         return data
 
     @classmethod
-    def from_exe(cls, exe, app_data=None, raise_on_error=True, ignore_cache=False, resolve_to_host=True):
+    def from_exe(cls, exe, app_data=None, raise_on_error=True, ignore_cache=False, resolve_to_host=True, env=None):
         """Given a path to an executable get the python information"""
         # this method is not used by itself, so here and called functions can import stuff locally
         from virtualenv.discovery.cached_py_info import from_exe
 
-        proposed = from_exe(cls, app_data, exe, raise_on_error=raise_on_error, ignore_cache=ignore_cache)
+        env = os.environ if env is None else env
+        proposed = from_exe(cls, app_data, exe, env=env, raise_on_error=raise_on_error, ignore_cache=ignore_cache)
         # noinspection PyProtectedMember
         if isinstance(proposed, PythonInfo) and resolve_to_host:
             try:
@@ -362,7 +412,7 @@ class PythonInfo(object):
 
     _cache_exe_discovery = {}
 
-    def discover_exe(self, app_data, prefix, exact=True):
+    def discover_exe(self, app_data, prefix, exact=True, env=None):
         key = prefix, exact
         if key in self._cache_exe_discovery and prefix:
             logging.debug("discover exe from cache %s - exact %s: %r", prefix, exact, self._cache_exe_discovery[key])
@@ -372,9 +422,10 @@ class PythonInfo(object):
         possible_names = self._find_possible_exe_names()
         possible_folders = self._find_possible_folders(prefix)
         discovered = []
+        env = os.environ if env is None else env
         for folder in possible_folders:
             for name in possible_names:
-                info = self._check_exe(app_data, folder, name, exact, discovered)
+                info = self._check_exe(app_data, folder, name, exact, discovered, env)
                 if info is not None:
                     self._cache_exe_discovery[key] = info
                     return info
@@ -387,11 +438,11 @@ class PythonInfo(object):
         msg = "failed to detect {} in {}".format("|".join(possible_names), os.pathsep.join(possible_folders))
         raise RuntimeError(msg)
 
-    def _check_exe(self, app_data, folder, name, exact, discovered):
+    def _check_exe(self, app_data, folder, name, exact, discovered, env):
         exe_path = os.path.join(folder, name)
         if not os.path.exists(exe_path):
             return None
-        info = self.from_exe(exe_path, app_data, resolve_to_host=False, raise_on_error=False)
+        info = self.from_exe(exe_path, app_data, resolve_to_host=False, raise_on_error=False, env=env)
         if info is None:  # ignore if for some reason we can't query
             return None
         for item in ["implementation", "architecture", "version_info"]:
@@ -448,7 +499,7 @@ class PythonInfo(object):
 
         # or at root level
         candidate_folder[inside_folder] = None
-        return list(i for i in candidate_folder.keys() if os.path.exists(i))
+        return [i for i in candidate_folder.keys() if os.path.exists(i)]
 
     def _find_possible_exe_names(self):
         name_candidate = OrderedDict()
@@ -486,4 +537,21 @@ class PythonInfo(object):
 if __name__ == "__main__":
     # dump a JSON representation of the current python
     # noinspection PyProtectedMember
-    print(PythonInfo()._to_json())
+    argv = sys.argv[1:]
+
+    if len(argv) >= 1:
+        start_cookie = argv[0]
+        argv = argv[1:]
+    else:
+        start_cookie = ""
+
+    if len(argv) >= 1:
+        end_cookie = argv[0]
+        argv = argv[1:]
+    else:
+        end_cookie = ""
+
+    sys.argv = sys.argv[:1] + argv
+
+    info = PythonInfo()._to_json()
+    sys.stdout.write("".join((start_cookie[::-1], info, end_cookie[::-1])))
